select 
    quote(@entry_type) as entry_type,
    quote(@dbsource) as database_name,
    quote(g.gname) as db_id,
    quote(concat(@dbname, "_", f.fid)) as db_version, # using to build unicity constraint over all documents (concat of entry_type, database_name, db_id and db_version Solr fields)
    quote(concat(g.gname,
        	' is a ',
            g.gclass,
            ' (type=', t.fmethod, ', source=', t.fsource,')',
            ' of ',
			@taxon,
			' located between positions ',
            f.fstart,
            ' and ',
            f.fstop,
--             ' on ',
--             ll.seqname,
            ' and which properties are ',
            props.attributes)) as description,
    quote(
	CASE WHEN g.gname LIKE '%:%' THEN concat(@url_base,replace(g.gname,':','%3A'))
   	     WHEN g.gname LIKE '%#%' THEN concat(@url_base,replace(g.gname,'#','%23'))
    ELSE concat(@url_base,g.gname) 
    END) as url,
    quote(@taxon) as species,
    quote("") as xref,
    quote(g.gclass) as feature_type,
    quote("") as sequence_id,
    quote("") as sequence_version,
    f.fstart as start_position,
    f.fstop as end_position,
    quote("") as map,
    quote("") as map_position,
    quote("") as authority,
    quote("") as trait,
    quote("") as trait_id,
    quote("") as environment,
    quote("") as environment_id,
    quote("") as statistic,
    quote("") as unit,
    quote("") as genotype,
    quote("") as experiment_type
from 
	(
    select f1.fid as fid,
    group_concat(
        concat_ws('=',a.fattribute_name,
            replace(atf.fattribute_value,'"',''))
    ) as attributes
    from fdata f1
    join ftype t on f1.ftypeid=t.ftypeid
    join fattribute_to_feature atf on atf.fid=f1.fid
    join fattribute a on atf.fattribute_id=a.fattribute_id
    group by fid
	) as props
join fdata f on f.fid = props.fid
join fgroup g on g.gid=f.gid
join ftype t on t.ftypeid=f.ftypeid
-- join locationlist ll on ll.id=f.seqid
-- where n.display_name=1 -- same as currently indexed in GnpIS quick search, cf l. 23 in gnpis-portal/core/src/main/java/fr/inra/genome/model/biodbseqfeature/Feature.hbm.xml
where g.gclass != 'Name'
order by f.fid
;
